@@ -1,5 +1,7 @@
 //! # Path Semantical Quality
 //!
+//! Path Semantical Quality is a partial equivalence relation that lifts biconditions
+//! with symbolic distinction.
 //! See [paper](https://github.com/advancedresearch/path_semantics/blob/master/papers-wip2/path-semantical-quality.pdf).
 //!
 //! For a different implementation of quality, see [PSI in Avalog](https://github.com/advancedresearch/avalog/blob/master/source/psi.txt).
@@ -16,6 +18,10 @@
 //! Since this is unsound without symbolic distinction,
 //! it is not possible to assume this directly.
 //!
+//! Although IPL does not support symbolic distinction,
+//! one can use `EqQ<A, B>` (`(a == b) => (a ~~ b)`) to model symbolic distinction.
+//! This means `EqQ<A, B>` can be used as an assumption that `A` and `B` are symbolic distinct.
+//!
 //! ### Seshatism vs Platonism
 //!
 //! [Seshatism](https://github.com/advancedresearch/path_semantics/blob/master/papers-wip2/seshatism.pdf)
@@ -27,6 +33,15 @@
 //!
 //! Since `a ~~ b` implies `a ~~ a`, both Loop and Product Witness are rejected by Seshatism.
 //!
+//! ### Seshatic Relations
+//!
+//! `Seshatic<A, B>`
+//!
+//! When a relation `p(a, b)` is Seshatic,
+//! it means that it implies Seshatism of either `a` or `b`:
+//!
+//! `p(a, b) => ¬(a ~~ a) ⋁ ¬(b ~~ b)`
+//!
 //! ### Pure Seshatism
 //!
 //! `PureSeshatism<A, B>` (feature flag is not needed)
@@ -85,6 +100,8 @@ pub type EqQ<A, B> = Imply<Eq<A, B>, Q<A, B>>;
 pub type PurePlatonism<A, B> = Imply<Eq<A, B>, Or<Q<A, B>, Not<Not<Q<A, B>>>>>;
 /// Pure Seshatism assumption.
 pub type PureSeshatism<A, B> = Imply<And<Not<Q<A, B>>, EqQ<A, B>>, Not<Eq<A, B>>>;
+/// A Seshatic relation `¬(a ~~ a) ⋁ ¬(b ~~ b)`.
+pub type Seshatic<A, B> = Or<Not<Q<A, A>>, Not<Q<B, B>>>;
 
 /// Prevents other qualities of `A` from excluding `B`.
 pub trait NoOtherQ<A, B>: 'static + Clone {
